import { OpenAPIV2 } from "openapi-types";
/** The registry to look up the name within. */
export declare enum RegistryKind {
    Definition = 0,
    Parameter = 1,
    Response = 2,
    SecurityDefinition = 3
}
export declare class CollectionRegistry {
    kind: RegistryKind;
    data: Map<string, any>;
    private unreferenced;
    constructor(data: Map<string, any>, key: string, kind: RegistryKind);
    /** Add or update an item. */
    add(name: string, value: any): void;
    /** Retrieve an item, if found. */
    get(name: string): any | undefined;
    /** Mark an item as referenced. */
    countReference(name: string): void;
    /** Resolve list of unreferenced objects. */
    getUnreferenced(): string[];
}
/** A class which contains all defintions which can be referenced in a spec. */
export declare class DefinitionRegistry {
    #private;
    private data;
    private polymorphicMap;
    private swaggerMap;
    private unresolvedReferences;
    private referenceStack;
    private referenceMap;
    constructor(map: Map<string, OpenAPIV2.Document>);
    /** Get a collection. */
    getCollection(registry: RegistryKind): any;
    /** Search a registry for a specific key. */
    get(name: string, registry?: RegistryKind): any | undefined;
    /** Logs a reference to an item. */
    countReference(name: string, registry: RegistryKind): void;
    /** Logs an unresolved reference. */
    logUnresolvedReference(ref: any): void;
    /** Returns unresolved references. */
    getUnresolvedReferences(): string[];
    /** Returns unreferenced items. */
    getUnreferenced(): Map<RegistryKind, string[]>;
    /** Returns the total number of unreferenced definitions. */
    getUnreferencedTotal(): number;
    /** Returns a list of references from the definition-gathering phase. */
    getReferences(key: string): string[];
}
//# sourceMappingURL=definitions.d.ts.map